@@ -1,6 +1,6 @@
 
 #ifndef _IMAGE_H_
-#define _IMAGE_H_ 1
+#define _IMAGE_H_ _IMAGE_H_
 
 #include <png.h>
 
