@@ -1,6 +1,6 @@
 
 #ifndef _MOON_H_
-#define _MOON_H_
+#define _MOON_H_ _MOON_H_
 
 #include <png.h>
 #include "image.h"
@@ -8,8 +8,8 @@
 struct moon_s
 {
    png_bytep bitmap;
-   int	     width;
-   int	     height;
+   int       width;
+   int       height;
    int       xbytes;
 };
 
